package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.IndexconfigIcon;

/**
 * 工作台图标Service接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface IIndexconfigIconService 
{
    /**
     * 查询工作台图标
     * 
     * @param id 工作台图标主键
     * @return 工作台图标
     */
    public IndexconfigIcon selectIndexconfigIconById(Long id);

    /**
     * 查询工作台图标列表
     * 
     * @param indexconfigIcon 工作台图标
     * @return 工作台图标集合
     */
    public List<IndexconfigIcon> selectIndexconfigIconList(IndexconfigIcon indexconfigIcon);

    /**
     * 新增工作台图标
     * 
     * @param indexconfigIcon 工作台图标
     * @return 结果
     */
    public int insertIndexconfigIcon(IndexconfigIcon indexconfigIcon);

    /**
     * 修改工作台图标
     * 
     * @param indexconfigIcon 工作台图标
     * @return 结果
     */
    public int updateIndexconfigIcon(IndexconfigIcon indexconfigIcon);

    /**
     * 批量删除工作台图标
     * 
     * @param ids 需要删除的工作台图标主键集合
     * @return 结果
     */
    public int deleteIndexconfigIconByIds(Long[] ids);

    /**
     * 删除工作台图标信息
     * 
     * @param id 工作台图标主键
     * @return 结果
     */
    public int deleteIndexconfigIconById(Long id);

    /**
     * 查询工作台图标
     *
     * @param identity 工作台图标身份
     * @return 工作台图标
     */
    public IndexconfigIcon getIndexconfigIconByIdentity(Long identity);
}
